##  Capabilities
  * Search for diagrams and reports: Easily search for diagrams and reports within SAP LeanIX. You can either navigate to a selected result or preview it within Joule, when available.
  * Search the inventory for fact sheets: You can search the inventory for fact sheets. You can either navigate to a chosen fact sheet or see more details within Joule.
  * Search SAP LeanIX documentation for information: Ask any questions related to SAP LeanIX, and Joule will provide answers based on the documentation. It summarizes the findings and offers a direct link to the source. If no direct information is found, Joule will try to answer using its training data.
  * View fact sheet subscriptions and contact subscribers: When you search for a fact sheet, you can directly access its subscribers and their roles and initiate an email right from the result.
  * View fact sheet to-dos: Search for a fact sheet and see its associated to-dos and their status within Joule.
  * Create to-dos for fact sheets: Quickly add new tasks or reminders to any fact sheet directly through Joule.
